Morpframework
=============

Morp is a python web development framework for developers who need a framework that provides some assistance in building applications that support distributed processing. Other web frameworks are primarily designed for standard wsgi processing, while distributed worker processing is primarily a feature that is added as a plugin, Morp is different in this sense because we try to make it a first class citizen of the framework.

For more information: https://morpframework.readthedocs.io/
